==> VirtualBoxSDK-5.1.2-108956.zip: org/virtualbox_5_1/jaxws/IMachineSetCPUIDLeaf.java <==

package org.virtualbox_5_1.jaxws;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="_this" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="id" type="{http://www.w3.org/2001/XMLSchema}unsignedInt"/>
 *         &lt;element name="valEax" type="{http://www.w3.org/2001/XMLSchema}unsignedInt"/>
 *         &lt;element name="valEbx" type="{http://www.w3.org/2001/XMLSchema}unsignedInt"/>
 *         &lt;element name="valEcx" type="{http://www.w3.org/2001/XMLSchema}unsignedInt"/>
 *         &lt;element name="valEdx" type="{http://www.w3.org/2001/XMLSchema}unsignedInt"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "_this",
    "id",
    "valEax",
    "valEbx",
    "valEcx",
    "valEdx"
})
@XmlRootElement(name = "IMachine_setCPUIDLeaf")
public class IMachineSetCPUIDLeaf {

    @XmlElement(required = true)
    protected String _this;
    @XmlSchemaType(name = "unsignedInt")
    protected long id;
    @XmlSchemaType(name = "unsignedInt")
    protected long valEax;
    @XmlSchemaType(name = "unsignedInt")
    protected long valEbx;
    @XmlSchemaType(name = "unsignedInt")
    protected long valEcx;
    @XmlSchemaType(name = "unsignedInt")
    protected long valEdx;

    /**
     * Gets the value of the this property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getThis() {
        return _this;
    }

    /**
     * Sets the value of the this property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setThis(String value) {
        this._this = value;
    }

    /**
     * Gets the value of the id property.
     * 
     */
    public long getId() {
        return id;
    }

    /**
     * Sets the value of the id property.
     * 
     */
    public void setId(long value) {
        this.id = value;
    }

    /**
     * Gets the value of the valEax property.
     * 
     */
    public long getValEax() {
        return valEax;
    }

    /**
     * Sets the value of the valEax property.
     * 
     */
    public void setValEax(long value) {
        this.valEax = value;
    }

    /**
     * Gets the value of the valEbx property.
     * 
     */
    public long getValEbx() {
        return valEbx;
    }

    /**
     * Sets the value of the valEbx property.
     * 
     */
    public void setValEbx(long value) {
        this.valEbx = value;
    }

    /**
     * Gets the value of the valEcx property.
     * 
     */
    public long getValEcx() {
        return valEcx;
    }

    /**
     * Sets the value of the valEcx property.
     * 
     */
    public void setValEcx(long value) {
        this.valEcx = value;
    }

    /**
     * Gets the value of the valEdx property.
     * 
     */
    public long getValEdx() {
        return valEdx;
    }

    /**
     * Sets the value of the valEdx property.
     * 
     */
    public void setValEdx(long value) {
        this.valEdx = value;
    }

}

==> VirtualBoxSDK-5.2.42-137960.zip: org/virtualbox_5_2/jaxws/IMachineSetCPUIDLeaf.java <==

package org.virtualbox_5_2.jaxws;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="_this" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="idx" type="{http://www.w3.org/2001/XMLSchema}unsignedInt"/>
 *         &lt;element name="idxSub" type="{http://www.w3.org/2001/XMLSchema}unsignedInt"/>
 *         &lt;element name="valEax" type="{http://www.w3.org/2001/XMLSchema}unsignedInt"/>
 *         &lt;element name="valEbx" type="{http://www.w3.org/2001/XMLSchema}unsignedInt"/>
 *         &lt;element name="valEcx" type="{http://www.w3.org/2001/XMLSchema}unsignedInt"/>
 *         &lt;element name="valEdx" type="{http://www.w3.org/2001/XMLSchema}unsignedInt"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "_this",
    "idx",
    "idxSub",
    "valEax",
    "valEbx",
    "valEcx",
    "valEdx"
})
@XmlRootElement(name = "IMachine_setCPUIDLeaf")
public class IMachineSetCPUIDLeaf {

    @XmlElement(required = true)
    protected String _this;
    @XmlSchemaType(name = "unsignedInt")
    protected long idx;
    @XmlSchemaType(name = "unsignedInt")
    protected long idxSub;
    @XmlSchemaType(name = "unsignedInt")
    protected long valEax;
    @XmlSchemaType(name = "unsignedInt")
    protected long valEbx;
    @XmlSchemaType(name = "unsignedInt")
    protected long valEcx;
    @XmlSchemaType(name = "unsignedInt")
    protected long valEdx;

    /**
     * Gets the value of the this property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getThis() {
        return _this;
    }

    /**
     * Sets the value of the this property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setThis(String value) {
        this._this = value;
    }

    /**
     * Gets the value of the idx property.
     * 
     */
    public long getIdx() {
        return idx;
    }

    /**
     * Sets the value of the idx property.
     * 
     */
    public void setIdx(long value) {
        this.idx = value;
    }

    /**
     * Gets the value of the idxSub property.
     * 
     */
    public long getIdxSub() {
        return idxSub;
    }

    /**
     * Sets the value of the idxSub property.
     * 
     */
    public void setIdxSub(long value) {
        this.idxSub = value;
    }

    /**
     * Gets the value of the valEax property.
     * 
     */
    public long getValEax() {
        return valEax;
    }

    /**
     * Sets the value of the valEax property.
     * 
     */
    public void setValEax(long value) {
        this.valEax = value;
    }

    /**
     * Gets the value of the valEbx property.
     * 
     */
    public long getValEbx() {
        return valEbx;
    }

    /**
     * Sets the value of the valEbx property.
     * 
     */
    public void setValEbx(long value) {
        this.valEbx = value;
    }

    /**
     * Gets the value of the valEcx property.
     * 
     */
    public long getValEcx() {
        return valEcx;
    }

    /**
     * Sets the value of the valEcx property.
     * 
     */
    public void setValEcx(long value) {
        this.valEcx = value;
    }

    /**
     * Gets the value of the valEdx property.
     * 
     */
    public long getValEdx() {
        return valEdx;
    }

    /**
     * Sets the value of the valEdx property.
     * 
     */
    public void setValEdx(long value) {
        this.valEdx = value;
    }

}
